@@ -9,11 +9,13 @@ require Exporter;
 
 use vars qw( @EXPORT_OK %EXPORT_TAGS );
 @EXPORT_OK = qw( @Scalars @Arrays @Hashes @Filehandles @Symbols
-                 @Functions @Barewords );
+                 @Functions @Barewords @TieIOMethods @UNIVERSALMethods
+                 @ExporterSymbols );
 %EXPORT_TAGS = ( 'all' => \@EXPORT_OK );
 
 use vars '$VERSION';
-$VERSION = '1.12';
+$VERSION = '1.16';
+my $CPERL = $^V =~ /c$/ ? 1 : 0;
 
 use vars '@Scalars';
 @Scalars = (
@@ -23,15 +25,16 @@ use vars '@Scalars';
         $& $MATCH
         $` $PREMATCH
         $' $POSTMATCH
-        $+ $LAST_PAREN_MATCH
-        $* $MULTILINE_MATCHING
-        $. $INPUT_LINE_NUMBER $NR
+        $+ $LAST_PAREN_MATCH ),
+    ($] < 5.008001 ?
+    qw( $* $MULTILINE_MATCHING) : ()),
+    qw( $. $INPUT_LINE_NUMBER $NR
         $/ $INPUT_RECORD_SEPARATOR $RS
-        $| $OUTPUT_AUTO_FLUSH ), '$,', qw( $OUTPUT_FIELD_SEPARATOR $OFS
+        $| $OUTPUT_AUTOFLUSH ), '$,', qw( $OUTPUT_FIELD_SEPARATOR $OFS
         $\ $OUTPUT_RECORD_SEPARATOR $ORS
         $" $LIST_SEPARATOR
         $; $SUBSCRIPT_SEPARATOR $SUBSEP
-        ), '$#', qw( $OFMT
+    ), '$#', qw( $OFMT
         $% $FORMAT_PAGE_NUMBER
         $= $FORMAT_LINES_PER_PAGE
         $- $FORMAT_LINES_LEFT
@@ -43,26 +46,31 @@ use vars '@Scalars';
         $@ $EVAL_ERROR
         $$ $PROCESS_ID $PID
         $< $REAL_USER_ID $UID
-        $> $EFFECTIVE_USER_ID $EUID ), '$(', qw( $REAL_GROUP_ID $GID ), '$)',
-    qw(
-        $EFFECTIVE_GROUP_ID $EGID
+        $> $EFFECTIVE_USER_ID $EUID ), 
+       '$(', qw( $REAL_GROUP_ID $GID ), 
+       '$)', qw( $EFFECTIVE_GROUP_ID $EGID
         $0 $PROGRAM_NAME
         $[
         $]
         $^A $ACCUMULATOR
         $^C $COMPILING
+        $^CHILD_ERROR_NATIVE
         $^D $DEBUGGING
         $^E $EXTENDED_OS_ERROR
         $^ENCODING
         $^F $SYSTEM_FD_MAX
+        $^GLOBAL_PHASE
         $^H
         $^I $INPLACE_EDIT
         $^L $FORMAT_FORMFEED
+        $^LAST_FH
         $^M
-        $^N
+        $^MATCH
+        $^N $LAST_SUBMATCH_RESULT
         $^O $OSNAME
         $^OPEN
         $^P $PERLDB
+        $^PREMATCH $^POSTMATCH
         $^R $LAST_REGEXP_CODE_RESULT
         $^RE_DEBUG_FLAGS
         $^RE_TRIE_MAXBUF
@@ -70,10 +78,12 @@ use vars '@Scalars';
         $^T $BASETIME
         $^TAINT
         $^UNICODE
+        $^UTF8CACHE
         $^UTF8LOCALE
         $^V $PERL_VERSION
         $^W $WARNING $^WARNING_BITS
         $^WIDE_SYSTEM_CALLS
+        $^WIN32_SLOPPY_STAT
         $^X $EXECUTABLE_NAME
         $ARGV
         ),
@@ -84,14 +94,17 @@ use vars '@Arrays';
     @+ $LAST_MATCH_END
     @- @LAST_MATCH_START
     @ARGV
+    @F
     @INC
-    @_
+    @_ @ARG
 );
 
 use vars '@Hashes';
 @Hashes = qw(
     %OVERLOAD
-    %!
+    %+ %LAST_MATCH_END
+    %- %LAST_MATCH_START
+    %! %OS_ERROR %ERRNO
     %^H
     %INC
     %ENV
@@ -101,21 +114,32 @@ use vars '@Hashes';
 use vars '@Filehandles';
 @Filehandles = qw(
     *ARGV ARGV
+    *_ _
     ARGVOUT
+    DATA
     STDIN
     STDOUT
     STDERR
 );
 
 use vars '@Functions';
-@Functions = qw(
+@Functions = (
+  ($] >= 5.015006 ? qw(
     __SUB__
+  ) : ()), qw(
     AUTOLOAD
     BEGIN
     DESTROY
-    END
-    INIT
-    CHECK
+    END ),
+    # STOP was between 5.5.64 - v5.6.0
+  ($] >= 5.005064 && $] < 5.006
+    ? qw(STOP) : qw(CHECK)),
+    # INIT was called RESTART before 5.004_50
+  ($] >= 5.006
+    ? qw(INIT) : qw(RESTART)),
+  ($] < 5.007003 ? qw(
+    EQ GE GT LE LT NE
+  ) : ()), qw(
     UNITCHECK
     abs
     accept
@@ -123,8 +147,10 @@ use vars '@Functions';
     atan2
     bind
     binmode
-    bless
+    bless ),
+  ($] >= 5.009003 && ($] < 5.027007 || $CPERL) ? qw(
     break
+  ) : ()), qw(
     caller
     chdir
     chmod
@@ -139,7 +165,10 @@ use vars '@Functions';
     cos
     crypt
     dbmclose
-    dbmopen
+    dbmopen ),
+  ($] >= 5.009003 && ($] < 5.027007 || $CPERL) ? qw(
+    default
+  ) : ()), qw(
     defined
     delete
     die
@@ -152,12 +181,17 @@ use vars '@Functions';
     endpwent
     endservent
     eof
-    eval
+    eval ),
+  ($] >= 5.015005 ? qw(
     evalbytes
+  ) : ()), qw(
     exec
     exists
     exit
+    exp ),
+  ($] >= 5.015008 ? qw(
     fc
+  ) : ()), qw(
     fcntl
     fileno
     flock
@@ -189,7 +223,10 @@ use vars '@Functions';
     getservbyport
     getservent
     getsockname
-    getsockopt
+    getsockopt ),
+  ($] >= 5.009003 ? qw(
+    given
+  ) : ()), qw(
     glob
     gmtime
     goto
@@ -197,6 +234,7 @@ use vars '@Functions';
     hex
     index
     int
+    import
     ioctl
     join
     keys
@@ -208,7 +246,10 @@ use vars '@Functions';
     link
     listen
     local
-    localtime
+    localtime ),
+  ($] >= 5.004 ? qw(
+    lock
+  ) : ()), qw(
     log
     lstat
     map
@@ -250,8 +291,10 @@ use vars '@Functions';
     reverse
     rewinddir
     rindex
-    rmdir
+    rmdir ),
+  ($] >= 5.009003 ? qw(
     say
+  ) : ()), qw(
     scalar
     seek
     seekdir
@@ -308,6 +351,7 @@ use vars '@Functions';
     umask
     undef
     unlink
+    unimport
     unpack
     unshift
     untie
@@ -318,7 +362,13 @@ use vars '@Functions';
     wait
     waitpid
     wantarray
-    warn
+    warn ),
+  ($] >= 5.009003 && ($] < 5.027007 || $CPERL) ? qw(
+    when
+  ) : qw(
+    whereis
+    whereso
+  )), qw(
     write
 
     -r -w -x -o
@@ -327,10 +377,11 @@ use vars '@Functions';
     -u -g -k
     -T -B
     -M -A -C
-);
+));
 
 use vars '@Barewords';
-@Barewords = qw(
+@Barewords = (
+  qw(
     __FILE__
     __LINE__
     __PACKAGE__
@@ -344,16 +395,20 @@ use vars '@Barewords';
     LT
     NE
     NULL
-    and
+    and ),
+  ($CPERL && $] >= 5.027001 ? qw(
+    class method role multi has
+  ) : ()), qw(
     cmp
     continue
     default
     do
     else
     elsif
-    eq
+    eq ),
+  ($] >= 5.008001 && $] < 5.010 ? qw(
     err
-    exp
+  ) : ()), qw(
     for
     foreach
     ge
@@ -369,8 +424,13 @@ use vars '@Barewords';
     or
     package
     q
-    qq
+    qq ),
+  ($] >= 5.004072 ? qw(
     qr
+  ) : ()),
+  ($] == 5.007003 ? qw(
+    qu
+  ) : ()), qw(
     qw
     qx
     s
@@ -383,6 +443,29 @@ use vars '@Barewords';
     x
     xor
     y
+));
+
+use vars '@TieIOMethods';
+@TieIOMethods = qw(
+    BINMODE CLEAR CLEARERR CLONE CLONE_SKIP CLOSE DELETE EOF
+    ERROR EXISTS EXTEND FDOPEN FETCH FETCHSIZE FILENO FILL FIRSTKEY FLUSH
+    GETC NEXTKEY OPEN POP POPPED PRINT PRINTF PUSH PUSHED READ READLINE
+    SCALAR SEEK SETLINEBUF SHIFT SPLICE STORE STORESIZE SYSOPEN TELL
+    TIEARRAY TIEHANDLE TIEHASH TIESCALAR UNREAD UNSHIFT UNTIE UTF8 WRITE
+);
+
+use vars '@UNIVERSALMethods';
+@UNIVERSALMethods = qw(
+    can isa DOES VERSION
+);
+
+use vars '@ExporterSymbols';
+@ExporterSymbols = qw(
+    @EXPORT @EXPORT_OK @EXPORT_FAIL
+    @EXPORT_TAGS _push_tags _rebuild_cache as_heavy export export_fail
+    export_fail_in export_ok_tags export_tags export_to_level heavy_export
+    heavy_export_ok_tags heavy_export_tags heavy_export_to_level
+    heavy_require_version require_version
 );
 
 use vars '@Symbols';
@@ -395,6 +478,8 @@ BEGIN { $^W = 0 }
 
 __END__
 
+=encoding UTF-8
+
 =head1 NAME
 
 B::Keywords - Lists of reserved barewords and symbol names
@@ -407,15 +492,25 @@ B::Keywords - Lists of reserved barewords and symbol names
 
 =head1 DESCRIPTION
 
-C<B::Keywords> supplies seven arrays of keywords: C<@Scalars>,
-C<@Arrays>, C<@Hashes>, C<@Filehandles>, C<@Symbols>, C<@Functions>,
-and C<@Barewords>. The C<@Symbols> array includes the contents of each
+C<B::Keywords> supplies several arrays of exportable keywords:
+C<@Scalars>, C<@Arrays>, C<@Hashes>, C<@Filehandles>, C<@Symbols>,
+C<@Functions>, C<@Barewords>, C<@TieIOMethods>, C<@UNIVERSALMethods>
+and C<@ExporterSymbols>.
+
+The C<@Symbols> array includes the contents of each
 of C<@Scalars>, C<@Arrays>, C<@Hashes>, C<@Functions> and C<@Filehandles>.
+
 Similarly, C<@Barewords> adds a few non-function keywords and
 operators to the C<@Functions> array.
 
 All additions and modifications are welcome.
 
+The perl parser uses a static list of keywords from
+F<regen/keywords.pl> which constitutes the strict list of keywords
+@Functions and @Barewords, though some @Functions are not functions
+in the strict sense.
+Several library functions use more special symbols, handles and methods.
+
 =head1 DATA
 
 =over
@@ -443,6 +538,21 @@ handles, and functions.
 This is a list of other special keywords in perl including operators
 and all the control structures.
 
+=item C<@TieIOMethods>
+
+Those are special tie or PerlIO methods called by the perl core,
+namely for tieing or PerlIO::via (or both of those) or threads.
+
+=item C<@UNIVERSALMethods>
+
+Methods defined by the core package UNIVERSAL.
+
+=item C<@ExporterSymbols>
+
+Variables or functions used by Exporter (some internal), which is
+almost as good as being keywords, for you mustn't use them for any
+other purpose in any package that isa Exporter, which is quite common.
+
 =back
 
 =head1 EXPORT
@@ -452,11 +562,9 @@ everything.
 
 =head1 SEE ALSO
 
-keywords.pl from the perl source, L<perlvar>, L<perlfunc>,
+F<regen/keywords.pl> from the perl source, L<perlvar>, L<perlfunc>,
 L<perldelta>.
 
-
-
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-B-Keywords at
@@ -495,11 +603,13 @@ L<http://search.cpan.org/dist/B-Keywords>
 
 =head1 ACKNOWLEDGEMENTS
 
-Michael G Schwern for patches
+Michael G Schwern, Reini Urban, Florian Ragwitz and Zsbán Ambrus
+for patches and releases.
 
 =head1 COPYRIGHT AND LICENSE
 
 Copyright 2009 Joshua ben Jore, All rights reserved.
+Copyright 2013, 2015, 2017 Reini Urban, All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of either:
@@ -511,8 +621,12 @@ b) the "Artistic License" which comes with Perl.
 
 =head1 SOURCE AVAILABILITY
 
-This source is in Github: L<git://github.com/jbenjore/b-keywords.git>
+This source is in Github: L<git://github.com/rurban/b-keywords.git>
 
 =head1 AUTHOR
 
 Joshua ben Jore <jjore@cpan.org>
+
+=head1 MAINTAINER
+
+Reini Urban <rurban@cpan.org>
